@@ -11,19 +11,11 @@ Elive::StandardV2::Multimedia - Multimedia entity class
 
 =head1 DESCRIPTION
 
-This class can be used to upload multimedia content, including:
+This command uploads supported multimedia files into your ELM repository for use by your Elluminate Live! sessions.
 
-=over 4
-
-=item MPEG files: C<.mpeg>, C<.mpg>, C<.mpe>, C<.m4v>, C<.mp3>, C<.mp4>
-
-=item QuickTime files: C<.mov>, C<.qt>
-
-=item Windows Media files: C<.wmv>
-
-=item Flash files: C<.swf>
-
-=back
+Once uploaded, you will need to "attach" the file to one or more Elluminate
+Live! sessions using the L<Elive::StandardV2::Session> C<set_multimedia()>
+method.
 
 =cut
 
@@ -37,24 +29,68 @@ __PACKAGE__->params(
     size => 'Int',
     );
 
+=head2 description (Str)
+
+A description of the multimedia content.
+
+=cut
+
 has 'description' => (is => 'rw', isa => 'Str');
+
+=head2 size (Int)
+
+The size of the multimedia file (bytes), once uploaded to the ELM repository.
+
+=cut
+
 has 'size' => (is => 'rw', isa => 'Int');
+
+=head2 creatorId (Str)
+
+The identifier of the owner of the multimedia file.
+
+=cut
+
 has 'creatorId' => (is => 'rw', isa => 'Str');
+
+=head2 filename (Str)
+
+The name of the multimedia file including the file extension.
+Elluminate Live! supports the following multimedia file types:
+
+=over 4
+
+=item (*) MPEG files: C<.mpeg>, C<.mpg>, C<.mpe>, C<.m4v>, C<.mp4>
+
+=item (*) QuickTime files: C<.mov>, C<.qt>
+
+=item (*) Windows Media files: C<.wmv>
+
+=item (*) Flash files: C<.swf>
+
+=item (*) Audio files: C<.mp3>
+
+=back
+
+The filename must be less than 64 characters (including any file extensions).
+
+=cut
+
 has 'filename' => (is => 'rw', isa => 'Str');
 
 =head1 METHODS
 
 =cut
 
-=head2 insert
+=head2 upload
 
-Uploads content and creates a new multimedia resource. You can either upload
-a file, or upload binary data for the multimedia content.
+Uploads content and creates a new multimedia resource. There are two formats:
 
-   # 1. upload a local file
-    my $multimedia = Elive::StandardV2::Multimedia->insert('c:\\Documents\intro.wav');
+    # 1. upload a local file
+    my $multimedia = Elive::StandardV2::Multimedia->upload('c:\\Documents\intro.wav');
 
-    # 2. stream it ourselves
+
+    # 2. source our own binary content
     open (my $fh, '<', $multimedia_path)
         or die "unable to open $multimedia_path: $!";
     $fh->binmode;
@@ -63,19 +99,21 @@ a file, or upload binary data for the multimedia content.
     die "no multimedia data: $multimedia_path"
         unless ($content);
 
-    my $multimedia = Elive::StandardV2::Multimedia->insert(
+    my $multimedia = Elive::StandardV2::Multimedia->upload(
              {
-                    filename => 'demo.wav',
+                    filename => 'whoops.wav',
                     creatorId =>  'alice',
                     content => $content,
+                    description => 'Caravan destroys service station',
 	     },
          );
+
 =cut
 
-sub insert {
-    my ($class, $insert_data, %opt) = @_;
+sub upload {
+    my ($class, $upload_data, %opt) = @_;
 
-    my $self = $class->SUPER::insert($insert_data,
+    my $self = $class->SUPER::upload($upload_data,
 				     command => 'uploadMultimediaContent',
 				     %opt);
 
@@ -105,4 +143,12 @@ sub list {
 	%opts);
 }
 
+=head2 delete
+
+    $multimedia->delete;
+
+Deletes multimedia content from the server and removes it from any associated sessions.
+
+=cut
+
 1;
