@@ -11,8 +11,11 @@ Elive::StandardV2::Presentation - Presentation entity class
 
 =head1 DESCRIPTION
 
-This class can be used to upload presentation content, including Elluminate
-I<Live!> plan files (C<*.elpx> etc) and whiteboard content C<*.wbd> etc).
+This command uploads presentation files, such as Elluminate C<Live!> whiteboard files or Elluminate I<Plan!> files into your ELM repository for use by your Elluminate Live! sessions.
+
+Once uploaded, you will need to "attach" the file to one or more Elluminate
+Live! sessions using the L<Elive::StandardV2::Session> C<set_presentation()>
+method.
 
 =cut
 
@@ -25,24 +28,63 @@ __PACKAGE__->params(
     sessionId => 'Int',
     );
 
+=head2 description (Str)
+
+A description of the presentation content.
+
+=cut
+
 has 'description' => (is => 'rw', isa => 'Str');
+
+=head2 size (Int)
+
+The size of the presentation file (bytes), once uploaded to the ELM repository.
+
+=cut
+
 has 'size' => (is => 'rw', isa => 'Int');
+
+=head2 creatorId (Str)
+
+The identifier of the owner of the presentation file.
+
+=cut
+
 has 'creatorId' => (is => 'rw', isa => 'Str');
+
+=head2 filename (Str)
+
+The name of the presentation file including the file extension.
+
+Elluminate Live! supports the following presentation file types:
+
+=over 4
+
+=item (*) Elluminate Live! Whiteboard files: C<.wbd>, C<.wbp>
+
+=item (*) Elluminate Plan! files: C<.elp>, C<.elpx>.
+
+=back
+
+Note: The filename must be less than 64 characters (including any file extensions)
+
+=cut
+
 has 'filename' => (is => 'rw', isa => 'Str');
 
 =head1 METHODS
 
 =cut
 
-=head2 insert
+=head2 upload
 
 Uploads content and creates a new presentation resource. You can either upload
 a file, or upload binary data for the presentation.
 
-   # 1. upload a local file
-    my $multimedia = Elive::StandardV2::Presentation->insert('c:\\Documents\intro.wbd');
+    # 1. upload a local file
+    my $presentation = Elive::StandardV2::Presentation->upload('c:\\Documents\intro.wbd');
 
-    # 2. stream it ourselves
+    # 2. source our own binary content
     open (my $fh, '<', $presentation_path)
         or die "unable to open $presentation_path: $!";
     $fh->binmode;
@@ -51,7 +93,7 @@ a file, or upload binary data for the presentation.
     die "no presentation data: $presentation_path"
         unless ($content);
 
-    my $presentation = Elive::StandardV2::Presentation->insert(
+    my $presentation = Elive::StandardV2::Presentation->upload(
              {
                     filename => 'myplan.elpx',
                     creatorId =>  'bob',
@@ -60,12 +102,12 @@ a file, or upload binary data for the presentation.
          );
 =cut
 
-sub insert {
-    my ($class, $insert_data, %opt) = @_;
+sub upload {
+    my ($class, $upload_data, %opt) = @_;
 
-    return $class->SUPER::insert($insert_data,
-				     command => 'uploadPresentationContent',
-				     %opt);
+    return $class->SUPER::upload($upload_data,
+				 command => 'uploadPresentationContent',
+				 %opt);
 }
 
 =head2 list
@@ -91,4 +133,13 @@ sub list {
 	%opts);
 }
 
+=head2 delete
+
+    $presentation->delete;
+
+Deletes presentation content from the server  and removes it from any associated sessions.
+
+=cut
+
+
 1;
